#!/bin/bash
# © Copyright [2016 - 2020] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.


if [ $# -eq 0 ]; then
    logger -t cis "Invalid Command. No arguments supplied.\n"
    exit 1;
fi

while [ "$1" != "" ]; do
case $1 in
        -type )        shift
                       request_type=$1
                       ;;
        -zk_uri )      shift
                       zk_uri=$1
                       ;;
        -cis_server )  shift
                       cis_server=$1
                       ;;
        -gw_external ) shift
                       gw_external=$1
                       ;;
        -gw_server )   shift
                       gw_server=$1
                       ;;
        -data_external )  shift
                       data_external=$1
                       ;;
        -data_server ) shift
                       data_server=$1
                       ;;
        -serverIp )    shift
                       data_server=$1
                       ;;
        -uuid )        shift
                       uuid=$1
                       ;;
        * )            >&2 echo "Invalid Arguement."
					   exit 1
					   ;; 
    esac
    shift
done

case $request_type in
        init ) 
                sed -i 's/^\(FW_ROUTE=\).*/\1"yes"/' /etc/sysconfig/SuSEfirewall2
                sysctl -w net.ipv4.ip_forward=1
                systemctl start containerd.socket
                if [ $? -ne 0 ]; then
                        logger -t cis "containerd.socket is not running.\n"
                        exit 1;
                fi
                systemctl start containerd.service
                if [ $? -ne 0 ]; then
                        logger -t cis "containerd.service is not running.\n"
                        exit 1;
                fi

                /opt/novell/cis/bin/disable_docker_iptables.sh
                if [ $? -ne 0 ]; then
                        logger -t cis "Failed to update docker options.\n"
                        exit 1;
                fi

                systemctl start docker
                if [ $? -ne 0 ]; then
                        logger -t cis "Docker is not running.\n"
                        exit 1;
                fi

                docker load -i /usr/share/suse-docker-images/sles-oes-cis-gateway-*
                docker load -i /usr/share/suse-docker-images/sles-oes-cis-data-*
                systemctl enable oes-cis-dataatscale.service > /dev/null 2>&1
                systemctl enable oes-cis-gatewayforscale.service > /dev/null 2>&1
                rpm -q --queryformat "%{VERSION} %{RELEASE}\n" sles-oes-cis-data-docker-image >/etc/opt/novell/cis-scale/VERSION
                ;;
        config )
                echo "Saving data on CIS-SCALE Config file in /etc/opt/novell/cis-scale/config"

                # Update general configuration file
                conf='/etc/opt/novell/cis-scale/config'
                if [ ! -f "$conf" ];then
                logger -t cis "Config file is not found.\n"
                exit 1; 
                fi
                
                # Updating UUID
                if [ ! -z "$uuid" ];then
                grep "^UUID" $conf
                if [[ $? -ne 0 ]]; then
                    echo -e "\n\nUUID=\"\"" >> $conf
                fi
                sed -i '/UUID/ c\UUID='$uuid'' $conf
                fi

                # Updating ZK URI
                if [ ! -z "$zk_uri" ];then
                sed -i '/ZK_URI/ c\ZK_URI='$zk_uri'' $conf
                fi

                # Updating CIS Server for Fluentd service
                if [ ! -z "$cis_server" ];then  
                sed -i '/CIS_SERVER/ c\CIS_SERVER='$cis_server'' $conf
                fi

                if [ ! -z "$gw_server" ];then
                # Reading Gateway config
                isGatewayExternal=$gw_external
                if [ "$isGatewayExternal" = true ]
                then
                        if [[ $gw_server =~ ^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$ ]]; then
                                sed -i '/SCALE_GATEWAY_SERVER/ c\SCALE_GATEWAY_SERVER='$gw_server'' $conf
                        else
                                gwIp=$(nslookup $gw_server | awk '/^Address: / { print $2;exit}')
                                sed -i '/SCALE_GATEWAY_SERVER/ c\SCALE_GATEWAY_SERVER='$gwIp'' $conf
                        fi
                else
                        if [[ $gw_server =~ ^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$ ]]; then
                                sed -i '/SCALE_GATEWAY_SERVER/ c\SCALE_GATEWAY_SERVER='$gw_server'' $conf
                        else
                                gwIp=$(nslookup $gw_server | awk '/^Address: / { print $2;exit}')
                                sed -i '/SCALE_GATEWAY_SERVER/ c\SCALE_GATEWAY_SERVER='$gwIp'' $conf
                        fi
                        systemctl enable oes-cis-gatewayforscale.service
                fi
                fi

                if [ ! -z "$data_server" ];then
                # Reading Data service config
                isDataExternal=$data_external
                if [ "$isDataExternal" = true ]
                then
                        if [[ $data_server =~ ^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$ ]]; then
                                sed -i '/SCALE_DATA_SERVER/ c\SCALE_DATA_SERVER='$data_server'' $conf
                        else
                                dataIp=$(nslookup $data_server | awk '/^Address: / { print $2;exit}')
                                sed -i '/SCALE_DATA_SERVER/ c\SCALE_DATA_SERVER='$dataIp'' $conf
                        fi
                else
                        if [[ $data_server =~ ^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$ ]]; then
                                sed -i '/SCALE_DATA_SERVER/ c\SCALE_DATA_SERVER='$data_server'' $conf
                        else
                                dataIp=$(nslookup $data_server | awk '/^Address: / { print $2;exit}')
                                sed -i '/SCALE_DATA_SERVER/ c\SCALE_DATA_SERVER='$dataIp'' $conf
                        fi
                        systemctl enable oes-cis-dataatscale.service
                fi
                fi
                ;;
        ports )
                # Opening Ports 8005,8301,8346 & 8347
                yast2 firewall services add tcpport=8005 zone=EXT
                yast2 firewall services show detailed zone=EXT 2>&1 | grep 'TCP' | grep 8005
                if [ $? -ne 0 ]; then
                        logger -t cis "Unable to open port 8005 in firewall EXT zone.\n"
                        exit 1;
                fi

                yast2 firewall services add tcpport=8343 zone=EXT
                yast2 firewall services show detailed zone=EXT 2>&1 | grep 'TCP' | grep 8343
                if [ $? -ne 0 ]; then
                        logger -t cis "Unable to open port 8343 in firewall EXT zone.\n"
                        exit 1;
                fi

                yast2 firewall services add tcpport=8347 zone=EXT
                yast2 firewall services show detailed zone=EXT 2>&1 | grep 'TCP' | grep 8347
                if [ $? -ne 0 ]; then
                        logger -t cis "Unable to open port 8347 in firewall EXT zone.\n"
                        exit 1;
                fi

                yast2 firewall services add tcpport=8301 zone=EXT
                yast2 firewall services show detailed zone=EXT 2>&1 | grep 'TCP' | grep 8301
                        if [ $? -ne 0 ]; then
                logger -t cis "Unable to open port 8301 in firewall EXT zone.\n"
                        exit 1;
                        fi

                isGatewayExternal=$gw_external
                        if [ "$isGatewayExternal" = false ]; then
                                yast2 firewall services add tcpport=8500 zone=EXT
                                yast2 firewall services show detailed zone=EXT 2>&1 | grep 'TCP' | grep 8500
                        fi
                ;;
        * )     >&2 echo "invalid scale config type"
		exit 1;

esac
